@@ -24,7 +24,7 @@ lazy_static! {
             ("A50M16", (99, 2.5)),
             ("A50N16", (120, 2.5)),
             ("A50Q16", (124, 2.5)),
-            ("AAVEUSDT", (89, 0.01)),
+            ("AAVEUSDT", (589, 0.01)),
             ("ADAF18", (260, 0.00000001)),
             ("ADAH18", (267, 0.00000001)),
             ("ADAH19", (323, 0.00000001)),
@@ -33,23 +33,23 @@ lazy_static! {
             ("ADAM18", (271, 0.00000001)),
             ("ADAM19", (331, 0.00000001)),
             ("ADAM20", (383, 0.00000001)),
-            ("ADAM21", (23, 0.00000001)),
+            ("ADAM21", (523, 0.00000001)),
             ("ADAU18", (286, 0.00000001)),
             ("ADAU19", (339, 0.00000001)),
             ("ADAU20", (398, 0.00000001)),
-            ("ADAU21", (70, 0.00000001)),
-            ("ADAUSD", (176, 0.0001)),
-            ("ADAUSDT", (21, 0.00001)),
+            ("ADAU21", (570, 0.00000001)),
+            ("ADAUSD", (676, 0.0001)),
+            ("ADAUSDT", (521, 0.00001)),
             ("ADAUSDTH21", (463, 0.00001)),
             ("ADAUSDTZ20", (431, 0.00001)),
             ("ADAZ18", (303, 0.00000001)),
             ("ADAZ19", (349, 0.00000001)),
             ("ADAZ20", (427, 0.00000001)),
-            ("ADAZ21", (138, 0.00000001)),
-            ("ALTMEXUSD", (116, 0.01)),
-            ("AVAXUSD", (175, 0.001)),
-            ("AXSUSD", (206, 0.01)),
-            ("AXSUSDT", (125, 0.001)),
+            ("ADAZ21", (638, 0.00000001)),
+            ("ALTMEXUSD", (616, 0.01)),
+            ("AVAXUSD", (675, 0.001)),
+            ("AXSUSD", (706, 0.01)),
+            ("AXSUSDT", (625, 0.001)),
             ("BCHF18", (256, 0.0001)),
             ("BCHH18", (266, 0.0001)),
             ("BCHH19", (322, 0.0001)),
@@ -58,23 +58,23 @@ lazy_static! {
             ("BCHM18", (272, 0.0001)),
             ("BCHM19", (330, 0.00001)),
             ("BCHM20", (382, 0.00001)),
-            ("BCHM21", (24, 0.00001)),
+            ("BCHM21", (524, 0.00001)),
             ("BCHU18", (285, 0.0001)),
             ("BCHU19", (338, 0.00001)),
             ("BCHU20", (397, 0.00001)),
-            ("BCHU21", (69, 0.000001)),
+            ("BCHU21", (569, 0.000001)),
             ("BCHUSD", (402, 0.05)),
             ("BCHX17", (239, 0.0001)),
             ("BCHZ17", (240, 0.0001)),
             ("BCHZ18", (302, 0.0001)),
             ("BCHZ19", (348, 0.00001)),
             ("BCHZ20", (426, 0.00001)),
-            ("BCHZ21", (137, 0.000001)),
+            ("BCHZ21", (637, 0.000001)),
             ("BFXQ16", (128, 0.0001)),
             ("BFXU16", (132, 0.0001)),
             ("BFXV16", (136, 0.0001)),
-            ("BNBUSD", (178, 0.01)),
-            ("BNBUSDT", (42, 0.01)),
+            ("BNBUSD", (678, 0.01)),
+            ("BNBUSDT", (542, 0.01)),
             ("BNBUSDTH21", (467, 0.0005)),
             ("BNBUSDTZ20", (451, 0.0005)),
             ("BVOL24H", (34, 0.01)),
@@ -92,11 +92,11 @@ lazy_static! {
             ("DASHM17", (186, 0.000001)),
             ("DASHU17", (209, 0.000001)),
             ("DASHZ17", (225, 0.000001)),
-            ("DEFIMEXUSD", (117, 0.01)),
-            ("DOGEUSD", (177, 0.00001)),
+            ("DEFIMEXUSD", (617, 0.01)),
+            ("DOGEUSD", (677, 0.00001)),
             ("DOGEUSDT", (476, 0.00001)),
-            ("DOTUSD", (179, 0.001)),
-            ("DOTUSDT", (19, 0.0005)),
+            ("DOTUSD", (679, 0.001)),
+            ("DOTUSDT", (519, 0.0005)),
             ("DOTUSDTH21", (469, 0.0005)),
             ("DOTUSDTZ20", (453, 0.0005)),
             ("EOSH19", (324, 0.0000001)),
@@ -105,20 +105,20 @@ lazy_static! {
             ("EOSM18", (279, 0.0000001)),
             ("EOSM19", (332, 0.0000001)),
             ("EOSM20", (384, 0.0000001)),
-            ("EOSM21", (25, 0.0000001)),
+            ("EOSM21", (525, 0.0000001)),
             ("EOSN17", (216, 0.000001)),
             ("EOSU18", (287, 0.0000001)),
             ("EOSU19", (340, 0.0000001)),
             ("EOSU20", (399, 0.0000001)),
-            ("EOSU21", (71, 0.00000001)),
-            ("EOSUSD", (207, 0.0001)),
-            ("EOSUSDT", (39, 0.0005)),
+            ("EOSU21", (571, 0.00000001)),
+            ("EOSUSD", (707, 0.0001)),
+            ("EOSUSDT", (539, 0.0005)),
             ("EOSUSDTH21", (464, 0.0005)),
             ("EOSUSDTZ20", (432, 0.0005)),
             ("EOSZ18", (304, 0.0000001)),
             ("EOSZ19", (350, 0.0000001)),
             ("EOSZ20", (428, 0.0000001)),
-            ("EOSZ21", (139, 0.00000001)),
+            ("EOSZ21", (639, 0.00000001)),
             ("ETC24H", (123, 0.000001)),
             ("ETC7D", (125, 0.000001)),
             ("ETH7D", (54, 0.00001)),
@@ -131,35 +131,35 @@ lazy_static! {
             ("ETHM18", (273, 0.00001)),
             ("ETHM19", (327, 0.00001)),
             ("ETHM20", (379, 0.00001)),
-            ("ETHM21", (26, 0.00001)),
+            ("ETHM21", (526, 0.00001)),
             ("ETHU17", (208, 0.00001)),
             ("ETHU18", (282, 0.00001)),
             ("ETHU19", (335, 0.00001)),
             ("ETHU20", (394, 0.00001)),
-            ("ETHU21", (66, 0.00001)),
+            ("ETHU21", (566, 0.00001)),
             ("ETHUSD", (297, 0.05)),
             ("ETHUSDH21", (462, 0.05)),
             ("ETHUSDM20", (386, 0.05)),
-            ("ETHUSDM21", (27, 0.05)),
+            ("ETHUSDM21", (527, 0.05)),
             ("ETHUSDU20", (401, 0.05)),
-            ("ETHUSDU21", (73, 0.05)),
+            ("ETHUSDU21", (573, 0.05)),
             ("ETHUSDZ20", (430, 0.05)),
-            ("ETHUSDZ21", (141, 0.05)),
+            ("ETHUSDZ21", (641, 0.05)),
             ("ETHXBT", (78, 0.00001)),
             ("ETHZ17", (224, 0.00001)),
             ("ETHZ18", (299, 0.00001)),
             ("ETHZ19", (345, 0.00001)),
             ("ETHZ20", (423, 0.00001)),
-            ("ETHZ21", (134, 0.00001)),
+            ("ETHZ21", (634, 0.00001)),
             ("FCT7D", (70, 0.000001)),
             ("FCTM17", (190, 0.000001)),
             ("FCTXBT", (93, 0.000001)),
-            ("FILUSDT", (56, 0.01)),
+            ("FILUSDT", (556, 0.01)),
             ("GNOM17", (184, 0.000001)),
-            ("LINKUSD", (208, 0.001)),
+            ("LINKUSD", (708, 0.001)),
             ("LINKUSDT", (441, 0.0005)),
             ("LINKUSDTH21", (465, 0.0005)),
-            ("LINKUSDTM21", (28, 0.0005)),
+            ("LINKUSDTM21", (528, 0.0005)),
             ("LINKUSDTZ20", (433, 0.0005)),
             ("LSKXBT", (98, 0.000001)),
             ("LTC7D", (150, 0.00001)),
@@ -171,47 +171,47 @@ lazy_static! {
             ("LTCM18", (274, 0.00001)),
             ("LTCM19", (328, 0.000005)),
             ("LTCM20", (380, 0.000005)),
-            ("LTCM21", (29, 0.000005)),
+            ("LTCM21", (529, 0.000005)),
             ("LTCU17", (211, 0.00001)),
             ("LTCU18", (283, 0.00001)),
             ("LTCU19", (336, 0.000005)),
             ("LTCU20", (395, 0.000005)),
-            ("LTCU21", (67, 0.000001)),
+            ("LTCU21", (567, 0.000001)),
             ("LTCUSD", (407, 0.01)),
             ("LTCXBT", (85, 0.00001)),
             ("LTCZ17", (227, 0.00001)),
             ("LTCZ18", (300, 0.00001)),
             ("LTCZ19", (346, 0.000005)),
             ("LTCZ20", (424, 0.000005)),
-            ("LTCZ21", (135, 0.000001)),
-            ("LUNAUSD", (149, 0.001)),
-            ("MATICUSDT", (88, 0.0001)),
+            ("LTCZ21", (635, 0.000001)),
+            ("LUNAUSD", (649, 0.001)),
+            ("MATICUSDT", (588, 0.0001)),
             ("NEOG18", (269, 0.000001)),
             ("NEOH18", (270, 0.000001)),
             ("QTUMU17", (195, 0.000001)),
             ("REP7D", (144, 0.000001)),
             ("SNTN17", (202, 0.00000001)),
-            ("SOLUSD", (209, 0.01)),
-            ("SOLUSDT", (49, 0.001)),
-            ("SRMUSDT", (132, 0.001)),
-            ("SUSHIUSDT", (118, 0.001)),
+            ("SOLUSD", (709, 0.01)),
+            ("SOLUSDT", (549, 0.001)),
+            ("SRMUSDT", (632, 0.001)),
+            ("SUSHIUSDT", (618, 0.001)),
             ("TRXH19", (325, 0.00000001)),
             ("TRXH20", (368, 0.00000001)),
             ("TRXH21", (461, 0.00000001)),
             ("TRXM19", (333, 0.00000001)),
             ("TRXM20", (385, 0.00000001)),
-            ("TRXM21", (30, 0.00000001)),
+            ("TRXM21", (530, 0.00000001)),
             ("TRXU18", (290, 0.00000001)),
             ("TRXU19", (341, 0.00000001)),
             ("TRXU20", (400, 0.00000001)),
-            ("TRXU21", (72, 0.0000000001)),
-            ("TRXUSDT", (40, 0.00001)),
+            ("TRXU21", (572, 0.0000000001)),
+            ("TRXUSDT", (540, 0.00001)),
             ("TRXZ18", (305, 0.00000001)),
             ("TRXZ19", (351, 0.00000001)),
             ("TRXZ20", (429, 0.00000001)),
-            ("TRXZ21", (140, 0.0000000001)),
-            ("UNIUSDT", (20, 0.001)),
-            ("VETUSDT", (81, 0.00001)),
+            ("TRXZ21", (640, 0.0000000001)),
+            ("UNIUSDT", (520, 0.001)),
+            ("VETUSDT", (581, 0.00001)),
             ("WINZ16", (156, 0.000001)),
             ("XBCH17", (158, 0.1)),
             ("XBCM17", (174, 0.1)),
@@ -230,9 +230,9 @@ lazy_static! {
             ("XBT7D_D95", (281, 0.00001)),
             ("XBT7D_U105", (280, 0.00001)),
             ("XBT7D_U110", (277, 0.00001)),
-            ("XBTEUR", (64, 0.5)),
-            ("XBTEURU21", (74, 0.5)),
-            ("XBTEURZ21", (142, 0.5)),
+            ("XBTEUR", (564, 0.5)),
+            ("XBTEURU21", (574, 0.5)),
+            ("XBTEURZ21", (642, 0.5)),
             ("XBTF15", (1, 0.01)),
             ("XBTF15_G15", (13, 0.01)),
             ("XBTF15_H15", (4, 0.01)),
@@ -245,7 +245,7 @@ lazy_static! {
             ("XBTH19", (298, 0.5)),
             ("XBTH20", (344, 0.5)),
             ("XBTH21", (422, 0.5)),
-            ("XBTH22", (133, 0.5)),
+            ("XBTH22", (633, 0.5)),
             ("XBTJ15", (26, 0.01)),
             ("XBTK15", (27, 0.01)),
             ("XBTK15_M15", (30, 0.01)),
@@ -267,11 +267,11 @@ lazy_static! {
             ("XBTU18", (276, 0.5)),
             ("XBTU19", (326, 0.5)),
             ("XBTU20", (378, 0.5)),
-            ("XBTU21", (32, 0.5)),
+            ("XBTU21", (532, 0.5)),
             ("XBTUSD", (88, 0.01)),
             ("XBTV15", (56, 0.01)),
-            ("XBTV21", (150, 0.5)),
-            ("XBTX21", (205, 0.5)),
+            ("XBTV21", (650, 0.5)),
+            ("XBTX21", (705, 0.5)),
             ("XBTZ14", (0, 0.01)),
             ("XBTZ14_F15", (2, 0.01)),
             ("XBTZ14_H15", (11, 0.01)),
@@ -281,7 +281,7 @@ lazy_static! {
             ("XBTZ18", (291, 0.5)),
             ("XBTZ19", (334, 0.5)),
             ("XBTZ20", (393, 0.5)),
-            ("XBTZ21", (65, 0.5)),
+            ("XBTZ21", (565, 0.5)),
             ("XBU24H", (22, 0.01)),
             ("XBU7D", (63, 0.01)),
             ("XBUH15", (6, 0.01)),
@@ -302,7 +302,7 @@ lazy_static! {
             ("XBUZ15", (37, 0.01)),
             ("XLMF18", (265, 0.00000001)),
             ("XLMH18", (268, 0.00000001)),
-            ("XLMUSDT", (22, 0.00001)),
+            ("XLMUSDT", (522, 0.00001)),
             ("XLT7D", (50, 0.001)),
             ("XMR7D", (131, 0.000001)),
             ("XMRH18", (253, 0.000001)),
@@ -319,18 +319,18 @@ lazy_static! {
             ("XRPM18", (275, 0.00000001)),
             ("XRPM19", (329, 0.00000001)),
             ("XRPM20", (381, 0.00000001)),
-            ("XRPM21", (31, 0.00000001)),
+            ("XRPM21", (531, 0.00000001)),
             ("XRPU17", (212, 0.00000001)),
             ("XRPU18", (284, 0.00000001)),
             ("XRPU19", (337, 0.00000001)),
             ("XRPU20", (396, 0.00000001)),
-            ("XRPU21", (68, 0.00000001)),
+            ("XRPU21", (568, 0.00000001)),
             ("XRPUSD", (377, 0.0001)),
             ("XRPZ17", (228, 0.00000001)),
             ("XRPZ18", (301, 0.00000001)),
             ("XRPZ19", (347, 0.00000001)),
             ("XRPZ20", (425, 0.00000001)),
-            ("XRPZ21", (136, 0.00000001)),
+            ("XRPZ21", (636, 0.00000001)),
             ("XTZUSDTH21", (466, 0.0005)),
             ("XTZUSDTZ20", (434, 0.0005)),
             ("XTZZ17", (215, 0.000001)),
@@ -381,7 +381,7 @@ fn fetch_tick_sizes() -> BTreeMap<String, (usize, f64)> {
                         tick_size.tickSize
                     };
                     if !tick_size.symbol.starts_with('.') {
-                        m.insert(tick_size.symbol, (index, real_tick_size));
+                        m.insert(tick_size.symbol, (start + index, real_tick_size));
                     }
                 }
                 if n < 500 {
@@ -389,7 +389,11 @@ fn fetch_tick_sizes() -> BTreeMap<String, (usize, f64)> {
                 } else {
                     start += 500;
                 }
+            } else {
+                break;
             }
+        } else {
+            break;
         }
     }
     m
@@ -660,6 +664,9 @@ mod tests {
 
         assert_eq!(3460.0, super::id_to_price("ETHUSD", 29699930800));
         assert_eq!(3451.0, super::id_to_price("ETHUSD", 29699930980));
+
+        assert_eq!(0.07369, super::id_to_price("ETHZ21", 63399992631));
+        assert_eq!(0.07216, super::id_to_price("ETHZ21", 63399992784));
     }
 
     #[test]
@@ -669,5 +676,8 @@ mod tests {
 
         assert_eq!(29699930800, super::price_to_id("ETHUSD", 3460.0));
         assert_eq!(29699930980, super::price_to_id("ETHUSD", 3451.0));
+
+        assert_eq!(63399992631, super::price_to_id("ETHZ21", 0.07369));
+        assert_eq!(63399992784, super::price_to_id("ETHZ21", 0.07216));
     }
 }
